kipartman
=====


Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

```
sudo apt-get install build-essential libgtk-3-dev libwebkitgtk-3.0-dev libwxgtk3.0-dev libwxgtk-media3.0-dev libwebkitgtk-dev libboost-dev
```

Compatibility
-------------

Licence
-------

Authors
-------

`kipartman` was written by `Sebastien Besombes`_.
